@@ -50,7 +50,7 @@
 # You should have received a copy of the GNU General Public License along
 # with EventGhost. If not, see <http://www.gnu.org/licenses/>.
 
-from . import cec
+from cec import cec
 import threading
 import eg
 
